summaryrefslogtreecommitdiffstats
path: root/pym
diff options
context:
space:
mode:
Diffstat (limited to 'pym')
-rw-r--r--pym/portage/package/ebuild/_config/KeywordsManager.py6
-rw-r--r--pym/portage/package/ebuild/_config/LicenseManager.py2
-rw-r--r--pym/portage/package/ebuild/config.py8
3 files changed, 8 insertions, 8 deletions
diff --git a/pym/portage/package/ebuild/_config/LicenseManager.py b/pym/portage/package/ebuild/_config/LicenseManager.py
index 627b03fa9..498fea275 100644
--- a/pym/portage/package/ebuild/_config/LicenseManager.py
+++ b/pym/portage/package/ebuild/_config/LicenseManager.py
@@ -156,7 +156,7 @@ class LicenseManager(object):
def getMissingLicenses(self, cpv, use, lic, slot):
"""
- Take a LICENSE string and return a list any licenses that the user may
+ Take a LICENSE string and return a list of any licenses that the user
may need to accept for the given package. The returned list will not
contain any licenses that have already been accepted. This method
can throw an InvalidDependString exception.
diff --git a/pym/portage/package/ebuild/config.py b/pym/portage/package/ebuild/config.py
index 16fb02f7b..733d36cfc 100644
--- a/pym/portage/package/ebuild/config.py
+++ b/pym/portage/package/ebuild/config.py
@@ -1451,9 +1451,9 @@ class config(object):
def _getMissingKeywords(self, cpv, metadata):
"""
Take a package and return a list of any KEYWORDS that the user may
- may need to accept for the given package. If the KEYWORDS are empty
+ need to accept for the given package. If the KEYWORDS are empty
and the the ** keyword has not been accepted, the returned list will
- contain ** alone (in order to distiguish from the case of "none
+ contain ** alone (in order to distinguish from the case of "none
missing").
@param cpv: The package name (for package.keywords support)
@@ -1475,7 +1475,7 @@ class config(object):
def _getMissingLicenses(self, cpv, metadata):
"""
- Take a LICENSE string and return a list any licenses that the user may
+ Take a LICENSE string and return a list of any licenses that the user
may need to accept for the given package. The returned list will not
contain any licenses that have already been accepted. This method
can throw an InvalidDependString exception.
@@ -1492,7 +1492,7 @@ class config(object):
def _getMissingProperties(self, cpv, metadata):
"""
- Take a PROPERTIES string and return a list of any properties the user may
+ Take a PROPERTIES string and return a list of any properties the user
may need to accept for the given package. The returned list will not
contain any properties that have already been accepted. This method
can throw an InvalidDependString exception.
diff --git a/pym/portage/package/ebuild/_config/KeywordsManager.py b/pym/portage/package/ebuild/_config/KeywordsManager.py
index 6df25fc1c..f6b866795 100644
--- a/pym/portage/package/ebuild/_config/KeywordsManager.py
+++ b/pym/portage/package/ebuild/_config/KeywordsManager.py
@@ -85,9 +85,9 @@ class KeywordsManager(object):
def getMissingKeywords(self, cpv, slot, keywords, global_accept_keywords, backuped_accept_keywords):
"""
Take a package and return a list of any KEYWORDS that the user may
- may need to accept for the given package. If the KEYWORDS are empty
+ need to accept for the given package. If the KEYWORDS are empty
and the the ** keyword has not been accepted, the returned list will
- contain ** alone (in order to distiguish from the case of "none
+ contain ** alone (in order to distinguish from the case of "none
missing").
@param cpv: The package name (for package.keywords support)
@@ -180,7 +180,7 @@ class KeywordsManager(object):
else:
if not mygroups:
# If KEYWORDS is empty then we still have to return something
# in order to distiguish from the case of "none missing".
mygroups.append("**")
missing = mygroups
return missing
@@ -180,7 +180,7 @@ class KeywordsManager(object):
if not mygroups:
# If KEYWORDS is empty then we still have to return something
- # in order to distiguish from the case of "none missing".
+ # in order to distinguish from the case of "none missing".
mygroups.append("**")
missing = mygroups